<span id="news-2023"></span>
# Changelog - 2023

## 21.2.0 - 2023-07-19

- fix thread worker: revert change considering connection as idle . 

!!! note
    This is fixing the bad file description error.
    
    21.1.0 - 2023-07-18


===================

- fix thread worker: fix socket removal from the queue

## 21.0.1 - 2023-07-17

- fix documentation build

## 21.0.0 - 2023-07-17

- support python 3.11
- fix gevent and eventlet workers
- fix threads support (gththread.md): improve performance and unblock requests
- SSL: now use SSLContext object
- HTTP parser: miscellaneous fixes
- remove unnecessary setuid calls
- fix testing
- improve logging
- miscellaneous fixes to core engine

*** RELEASE NOTE ***

We made this release major to start our new release cycle. More info will be provided on our discussion forum.
